using System;
using ELTE.TravelAgency.Web;
using Microsoft.AspNetCore.Builder;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using ELTE.TravelAgency.Web.Models;


var builder = WebApplication.CreateBuilder(args);

// Add services to the container.
builder.Services.AddDbContext<TravelAgencyContext>(options => // Dependency injection belltsa az adatbzis kontextushoz
    options.UseSqlServer(builder.Configuration.GetConnectionString("DefaultConnection")));

// Dependency injection belltsa a Google konfigurci kollekcihoz
builder.Services.Configure<GoogleConfig>(builder.Configuration.GetSection("Google"));

// Dependency injection belltsa az utazssal kapcsolatos szolgltatshoz
builder.Services.AddTransient<ITravelService, TravelService>();
// Dependency injection belltsa a felhasznlkezelssel kapcsolatos szolgltatshoz
builder.Services.AddTransient<IAccountService, AccountService>();
// Dependency injection belltsa az alkalmazs llapotra
builder.Services.AddSingleton<ApplicationState>();
// Dependency injection a IHttpContextAccessor-hoz
builder.Services.AddHttpContextAccessor();

builder.Services.AddControllersWithViews();

// Munkamenetkezels belltsa
//builder.Services.AddDistributedMemoryCache();
builder.Services.AddSession(options =>
{
    options.IdleTimeout = TimeSpan.FromMinutes(15); // max. 15 percig l a munkamenet
});


var app = builder.Build();

// Configure the HTTP request pipeline.
if (!app.Environment.IsDevelopment())
{
    app.UseExceptionHandler("/Home/Error");
    // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
    app.UseHsts();
}

app.UseHttpsRedirection();
app.UseStaticFiles();

app.UseRouting();

app.UseAuthorization();

// Munkamentek hasznlata
app.UseSession();

app.MapControllerRoute(
    name: "default",
    pattern: "{controller=Home}/{action=Index}/{id?}");

using (var serviceScope = app.Services.CreateScope())
{
    // Adatbzis inicializlsa
    DbInitializer.Initialize(
        serviceScope.ServiceProvider,
        builder.Configuration.GetValue<string>("ImageStore"));
}

app.Run();